@@ -1,10 +1,10 @@
 package Zoidberg::Fish::Intel;
 
-our $VERSION = '0.94';
+our $VERSION = '0.97';
 
 use strict;
 use vars qw/$DEVNULL/;
-use AutoLoader 'AUTOLOAD';
+#use AutoLoader 'AUTOLOAD';
 use Zoidberg::Fish;
 use Zoidberg::Utils qw/:default path list_path list_dir/;
 
@@ -290,9 +290,9 @@ sub i_dirs_n_files { # types can be x, f, ans/or d # TODO globbing tab :)
 sub i_perl { return ($_[1], qw/_zoid env_vars dirs_n_files/) }
 # FIXME how bout completing commands as subs ?
 
-1;
+#1;
 
-__END__
+#__END__
 
 sub i__zoid {
 	my ($self, $block) = @_;
@@ -482,7 +482,7 @@ FIXME
 
 Jaap Karssenberg || Pardus [Larus] E<lt>pardus@cpan.orgE<gt>
 
-Copyright (c) 2002 Jaap G Karssenberg. All rights reserved.
+Copyright (c) 2011 Jaap G Karssenberg and Joel Berger. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
@@ -492,3 +492,5 @@ L<Zoidberg>, L<Zoidberg::Fish>,
 
 =cut
 
+1;
+
